function varargout = beenden(varargin)
% BEENDEN MATLAB code for beenden.fig
%      BEENDEN, by itself, creates a new BEENDEN or raises the existing
%      singleton*.
%
%      H = BEENDEN returns the handle to a new BEENDEN or the handle to
%      the existing singleton*.
%
%      BEENDEN('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in BEENDEN.M with the given input arguments.
%
%      BEENDEN('Property','Value',...) creates a new BEENDEN or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before beenden_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to beenden_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help beenden

% Last Modified by GUIDE v2.5 25-Jun-2015 19:27:50

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @beenden_OpeningFcn, ...
                   'gui_OutputFcn',  @beenden_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before beenden is made visible.
function beenden_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to beenden (see VARARGIN)

% Choose default command line output for beenden
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes beenden wait for user response (see UIRESUME)
% uiwait(handles.figure1);

beend = 0;
assignin('base','beend',beend);

% --- Outputs from this function are returned to the command line.
function varargout = beenden_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

beend=1
assignin('base','beend',beend);